import cv2 as cv
import numpy as np
import os
from PIL import Image
import tkinter as tk

class ImageIO:
    def __init__(self, shared_data):
        self.shared_data = shared_data

    def load_image(self, path):
        return cv.imread(path, cv.IMREAD_COLOR)

    def write_image(self, img, fileName="image.png"):
        if cv.imwrite(fileName, img):
            print(f"File {fileName} Written Successfully")
        else:
            print("File writing failed")

    def show_image(self, img, title="Image Title", canvas=None):
        # Set up OpenCV fullscreen window in the main thread
        cv.namedWindow(title, cv.WINDOW_NORMAL)
        cv.setWindowProperty(title, cv.WND_PROP_FULLSCREEN, cv.WINDOW_FULLSCREEN)
        
        # Resize the image to 1920x1080 resolution
        img_resized = cv.resize(img, (1920, 1080), interpolation=cv.INTER_LINEAR)
        
        # Display the resized image in OpenCV and keep it open without blocking Tkinter
        cv.imshow(title, img_resized)

        # Run a non-blocking loop to keep OpenCV window and Tkinter GUI responsive
        while cv.getWindowProperty(title, cv.WND_PROP_VISIBLE) >= 1:
            cv.waitKey(1)
            if canvas:
                canvas.update_idletasks()
                canvas.update()

        # Close the OpenCV window once the loop ends
        cv.destroyAllWindows()